@@ -2,7 +2,7 @@ from typing import Generic, TYPE_CHECKING, Tuple
 
 import attr
 
-from opyoid.target import Target
+from opyoid.frozen_target import FrozenTarget
 from opyoid.typings import InjectedT
 from .binding import Binding
 
@@ -14,4 +14,4 @@ if TYPE_CHECKING:
 class RegisteredBinding(Generic[InjectedT]):
     raw_binding: Binding[InjectedT]
     source_path: Tuple["PrivateModule", ...] = attr.Factory(tuple)
-    target: Target[InjectedT] = attr.Factory(lambda self: self.raw_binding.target, takes_self=True)
+    target: FrozenTarget[InjectedT] = attr.Factory(lambda self: self.raw_binding.target, takes_self=True)
