@@ -2,7 +2,7 @@ from opyoid.bindings import SelfBinding
 from opyoid.injection_state import InjectionState
 from opyoid.provider import Provider
 from opyoid.target import Target
-from opyoid.typings import InjectedT
+from opyoid.typings import EMPTY, InjectedT
 from .from_binding_provider_factory import FromBindingProviderFactory
 from .provider_factory import ProviderFactory
 
@@ -12,7 +12,7 @@ class JitProviderFactory(ProviderFactory):
         self.provider_factory = FromBindingProviderFactory()
 
     def accept(self, target: Target[InjectedT], state: InjectionState) -> bool:
-        return state.options.auto_bindings and not state.current_binding_has_fallback
+        return state.options.auto_bindings and target.default is EMPTY and not isinstance(target.type, str)
 
     def create(self, target: Target[InjectedT], state: InjectionState) -> Provider[InjectedT]:
         return self.provider_factory.create_from_binding(SelfBinding(target.type, annotation=target.annotation), state)
